==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/message/impl/AsynchronousMessageSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.message.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.message.AsynchronousMessage;
import io.ciera.tool.sql.ooaofooa.message.AsynchronousMessageSet;
import io.ciera.tool.sql.ooaofooa.message.EventMessageSet;
import io.ciera.tool.sql.ooaofooa.message.InformalAsynchronousMessageSet;
import io.ciera.tool.sql.ooaofooa.message.MSG_MSet;
import io.ciera.tool.sql.ooaofooa.message.SignalMessageSet;
import io.ciera.tool.sql.ooaofooa.message.impl.EventMessageSetImpl;
import io.ciera.tool.sql.ooaofooa.message.impl.InformalAsynchronousMessageSetImpl;
import io.ciera.tool.sql.ooaofooa.message.impl.MSG_MSetImpl;
import io.ciera.tool.sql.ooaofooa.message.impl.SignalMessageSetImpl;

import java.util.Arrays;
import java.util.List;


public class AsynchronousMessageSetImpl extends InstanceSet<AsynchronousMessageSet,AsynchronousMessage> implements AsynchronousMessageSet {

    // attributes
    @Override
    public void setMsg_ID( UniqueId ref_Msg_ID ) throws XtumlException {
        for ( AsynchronousMessage asynchronousmessage : this ) asynchronousmessage.setMsg_ID( ref_Msg_ID );
    }
    @Override
    public void setDurationConstraint( String m_DurationConstraint ) throws XtumlException {
        for ( AsynchronousMessage asynchronousmessage : this ) asynchronousmessage.setDurationConstraint( m_DurationConstraint );
    }
    @Override
    public void setIsFormal( boolean m_isFormal ) throws XtumlException {
        for ( AsynchronousMessage asynchronousmessage : this ) asynchronousmessage.setIsFormal( m_isFormal );
    }
    @Override
    public void setLabel( String m_Label ) throws XtumlException {
        for ( AsynchronousMessage asynchronousmessage : this ) asynchronousmessage.setLabel( m_Label );
    }
    @Override
    public void setDurationObservation( String m_DurationObservation ) throws XtumlException {
        for ( AsynchronousMessage asynchronousmessage : this ) asynchronousmessage.setDurationObservation( m_DurationObservation );
    }
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( AsynchronousMessage asynchronousmessage : this ) asynchronousmessage.setDescrip( m_Descrip );
    }
    @Override
    public void setSequenceNumb( String m_SequenceNumb ) throws XtumlException {
        for ( AsynchronousMessage asynchronousmessage : this ) asynchronousmessage.setSequenceNumb( m_SequenceNumb );
    }
    @Override
    public void setInformalName( String m_InformalName ) throws XtumlException {
        for ( AsynchronousMessage asynchronousmessage : this ) asynchronousmessage.setInformalName( m_InformalName );
    }
    @Override
    public void setGuardCondition( String m_GuardCondition ) throws XtumlException {
        for ( AsynchronousMessage asynchronousmessage : this ) asynchronousmessage.setGuardCondition( m_GuardCondition );
    }


    // selections
    @Override
    public MSG_MSet R1018_is_a_MSG_M() throws XtumlException {
        MSG_MSet msg_mset = new MSG_MSetImpl();
        for ( AsynchronousMessage asynchronousmessage : this ) msg_mset.add( asynchronousmessage.R1018_is_a_MSG_M() );
        return msg_mset;
    }
    @Override
    public EventMessageSet R1019_is_a_EventMessage() throws XtumlException {
        EventMessageSet eventmessageset = new EventMessageSetImpl();
        for ( AsynchronousMessage asynchronousmessage : this ) eventmessageset.add( asynchronousmessage.R1019_is_a_EventMessage() );
        return eventmessageset;
    }
    @Override
    public InformalAsynchronousMessageSet R1019_is_a_InformalAsynchronousMessage() throws XtumlException {
        InformalAsynchronousMessageSet informalasynchronousmessageset = new InformalAsynchronousMessageSetImpl();
        for ( AsynchronousMessage asynchronousmessage : this ) informalasynchronousmessageset.add( asynchronousmessage.R1019_is_a_InformalAsynchronousMessage() );
        return informalasynchronousmessageset;
    }
    @Override
    public SignalMessageSet R1019_is_a_SignalMessage() throws XtumlException {
        SignalMessageSet signalmessageset = new SignalMessageSetImpl();
        for ( AsynchronousMessage asynchronousmessage : this ) signalmessageset.add( asynchronousmessage.R1019_is_a_SignalMessage() );
        return signalmessageset;
    }


    @Override
    public AsynchronousMessage nullElement() {
        return AsynchronousMessageImpl.EMPTY_ASYNCHRONOUSMESSAGE;
    }

    @Override
    public AsynchronousMessageSet emptySet() {
      return new AsynchronousMessageSetImpl();
    }

    @Override
    public AsynchronousMessageSet value() {
        return this;
    }

    @Override
    public List<AsynchronousMessage> elements() {
        return Arrays.asList(toArray(new AsynchronousMessage[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/message/impl/AsynchronousMessageSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.message.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.message.AsynchronousMessage;
import io.ciera.tool.sql.ooaofooa.message.AsynchronousMessageSet;
import io.ciera.tool.sql.ooaofooa.message.EventMessageSet;
import io.ciera.tool.sql.ooaofooa.message.InformalAsynchronousMessageSet;
import io.ciera.tool.sql.ooaofooa.message.MSG_MSet;
import io.ciera.tool.sql.ooaofooa.message.SignalMessageSet;
import io.ciera.tool.sql.ooaofooa.message.impl.EventMessageSetImpl;
import io.ciera.tool.sql.ooaofooa.message.impl.InformalAsynchronousMessageSetImpl;
import io.ciera.tool.sql.ooaofooa.message.impl.MSG_MSetImpl;
import io.ciera.tool.sql.ooaofooa.message.impl.SignalMessageSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class AsynchronousMessageSetImpl extends InstanceSet<AsynchronousMessageSet,AsynchronousMessage> implements AsynchronousMessageSet {

    public AsynchronousMessageSetImpl() {
    }

    public AsynchronousMessageSetImpl(Comparator<? super AsynchronousMessage> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setMsg_ID( UniqueId ref_Msg_ID ) throws XtumlException {
        for ( AsynchronousMessage asynchronousmessage : this ) asynchronousmessage.setMsg_ID( ref_Msg_ID );
    }
    @Override
    public void setLabel( String m_Label ) throws XtumlException {
        for ( AsynchronousMessage asynchronousmessage : this ) asynchronousmessage.setLabel( m_Label );
    }
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( AsynchronousMessage asynchronousmessage : this ) asynchronousmessage.setDescrip( m_Descrip );
    }
    @Override
    public void setInformalName( String m_InformalName ) throws XtumlException {
        for ( AsynchronousMessage asynchronousmessage : this ) asynchronousmessage.setInformalName( m_InformalName );
    }
    @Override
    public void setIsFormal( boolean m_isFormal ) throws XtumlException {
        for ( AsynchronousMessage asynchronousmessage : this ) asynchronousmessage.setIsFormal( m_isFormal );
    }
    @Override
    public void setDurationObservation( String m_DurationObservation ) throws XtumlException {
        for ( AsynchronousMessage asynchronousmessage : this ) asynchronousmessage.setDurationObservation( m_DurationObservation );
    }
    @Override
    public void setDurationConstraint( String m_DurationConstraint ) throws XtumlException {
        for ( AsynchronousMessage asynchronousmessage : this ) asynchronousmessage.setDurationConstraint( m_DurationConstraint );
    }
    @Override
    public void setSequenceNumb( String m_SequenceNumb ) throws XtumlException {
        for ( AsynchronousMessage asynchronousmessage : this ) asynchronousmessage.setSequenceNumb( m_SequenceNumb );
    }
    @Override
    public void setGuardCondition( String m_GuardCondition ) throws XtumlException {
        for ( AsynchronousMessage asynchronousmessage : this ) asynchronousmessage.setGuardCondition( m_GuardCondition );
    }


    // selections
    @Override
    public MSG_MSet R1018_is_a_MSG_M() throws XtumlException {
        MSG_MSet msg_mset = new MSG_MSetImpl();
        for ( AsynchronousMessage asynchronousmessage : this ) msg_mset.add( asynchronousmessage.R1018_is_a_MSG_M() );
        return msg_mset;
    }
    @Override
    public EventMessageSet R1019_is_a_EventMessage() throws XtumlException {
        EventMessageSet eventmessageset = new EventMessageSetImpl();
        for ( AsynchronousMessage asynchronousmessage : this ) eventmessageset.add( asynchronousmessage.R1019_is_a_EventMessage() );
        return eventmessageset;
    }
    @Override
    public InformalAsynchronousMessageSet R1019_is_a_InformalAsynchronousMessage() throws XtumlException {
        InformalAsynchronousMessageSet informalasynchronousmessageset = new InformalAsynchronousMessageSetImpl();
        for ( AsynchronousMessage asynchronousmessage : this ) informalasynchronousmessageset.add( asynchronousmessage.R1019_is_a_InformalAsynchronousMessage() );
        return informalasynchronousmessageset;
    }
    @Override
    public SignalMessageSet R1019_is_a_SignalMessage() throws XtumlException {
        SignalMessageSet signalmessageset = new SignalMessageSetImpl();
        for ( AsynchronousMessage asynchronousmessage : this ) signalmessageset.add( asynchronousmessage.R1019_is_a_SignalMessage() );
        return signalmessageset;
    }


    @Override
    public AsynchronousMessage nullElement() {
        return AsynchronousMessageImpl.EMPTY_ASYNCHRONOUSMESSAGE;
    }

    @Override
    public AsynchronousMessageSet emptySet() {
      return new AsynchronousMessageSetImpl();
    }

    @Override
    public AsynchronousMessageSet emptySet(Comparator<? super AsynchronousMessage> comp) {
      return new AsynchronousMessageSetImpl(comp);
    }

    @Override
    public AsynchronousMessageSet value() {
        return this;
    }

    @Override
    public List<AsynchronousMessage> elements() {
        return Arrays.asList(toArray(new AsynchronousMessage[0]));
    }

}
